@@ -14,12 +14,12 @@ def main():
   parser = argparse.ArgumentParser()
   parser.add_argument('--seed', type=int, default=None)
   parser.add_argument('--area', nargs=2, type=int, default=(64, 64))
-  parser.add_argument('--view', type=int, default=4)
+  parser.add_argument('--view', type=int, default=6)
   parser.add_argument('--length', type=int, default=None)
   parser.add_argument('--health', type=int, default=10)
-  parser.add_argument('--window', type=int, default=500)
+  parser.add_argument('--window', type=int, default=800)
   parser.add_argument('--record', type=str, default=None)
-  parser.add_argument('--fps', type=int, default=3)
+  parser.add_argument('--fps', type=int, default=5)
   args = parser.parse_args()
 
   keymap = {
@@ -48,6 +48,9 @@ def main():
   if args.record:
     frames = []
 
+  diamond = crafter.crafter.MATERIAL_IDS['diamond']
+  print('\nDiamonds:', (env._terrain == diamond).sum())
+
   pygame.init()
   screen = pygame.display.set_mode([args.window, args.window])
   clock = pygame.time.Clock()
@@ -93,8 +96,9 @@ def main():
       print('\nDone:', done)
 
     if args.record:
-      frames.append(obs['image'].transpose((1, 0, 2)))
-    surface = pygame.surfarray.make_surface(obs['image'])
+      frames.append(obs['image'])
+    surface = pygame.surfarray.make_surface(
+        obs['image'].transpose((1, 0, 2)))
     screen.blit(surface, (0, 0))
     pygame.display.flip()
     clock.tick(args.fps)
